# PYSILICO server: Prosilica AVT camera controller for Plico

[![Build Status][travis]][travislink]  [![Coverage Status][coveralls]][coverallslink]  [![PyPI version][pypiversion]][pypiversionlink]  

pysilico is an application to control [Allied AVT/Prosilica][allied] cameras (and possibly other GigE cameras) under the [plico][plico] environment.

See [pysilico][pysilico] for installation and usage

[plico]: https://github.com/lbusoni/plico
[pysilico]: https://github.com/lbusoni/pysilico
[allied]: https://www.alliedvision.com
[travis]: https://travis-ci.com/lbusoni/pysilico_server.svg?branch=master "go to travis"
[travislink]: https://travis-ci.com/lbusoni/pysilico_server
[coveralls]: https://coveralls.io/repos/github/lbusoni/pysilico_server/badge.svg?branch=master "go to coveralls"
[coverallslink]: https://coveralls.io/github/lbusoni/pysilico_server
[pypiversion]: https://badge.fury.io/py/pysilico-server.svg
[pypiversionlink]: https://badge.fury.io/py/pysilico_server
